@@ -41,5 +41,6 @@ tar_nix_ga <- function() {
     message("GitHub Actions workflow file saved to: ", path)
   }
 
-  if (identical(Sys.getenv("TESTTHAT"), "true")) paste0(path, "/run-pipeline.yaml")
+  if (identical(Sys.getenv("TESTTHAT"), "true"))
+    paste0(path, "/run-pipeline.yaml")
 }
